@@ -1,11 +1,11 @@
-# -*- coding: utf-8 -*-
 __author__ = """Jimmy Shen"""
 __email__ = "jmmshn@gmail.com"
 __version__ = "0.1.0"
 
-from pkg_resources import get_distribution, DistributionNotFound
 import os
 
+from pkg_resources import DistributionNotFound, get_distribution
+
 try:
     __version__ = get_distribution(__name__).version
 except DistributionNotFound:
